@@ -16,9 +16,12 @@
 # along with python-iam.  If not, see <https://www.gnu.org/licenses/>.
 
 
-DEFAULT_GROUP1 = 'group1@test.groups.iam.unimatrixone.io'
-DEFAULT_PASSWORD = "password"
-DEFAULT_SITE_ID = 1
-DEFAULT_SUPERUSER = "superuser@test.unimatrixone.io"
-DEFAULT_USER1 = "user1@test.unimatrixone.io"
-DEFAULT_USER2 = "user2@test.unimatrixone.io"
+TEST_USER1_ID           = '00000000-0000-0000-0000-000000000001'
+TEST_USER1_EMAIL        = 'testuser1@test.iam.unimatrixone.io'
+TEST_USER1_PHONENUMBER  = "+31612345678"
+TEST_PASSWORD           = 'password'
+
+
+MESSAGE_QUERY_PARAM = 'm'
+
+MESSAGE_TOKEN_SESSION_KEY = 'iam.token'
