@@ -33,7 +33,7 @@ class EmailPrincipal(Principal):
 
     def __init__(self, email):
         super().__init__()
-        self.email = email
+        self.email = str.lower(email)
 
     @ioc.inject('service', 'EmailService')
     def send(self, service, subject, text, html=None, sender=None):
